@@ -1,4 +1,4 @@
-# Copyright 2013 tsuru-circus authors. All rights reserved.
+# Copyright 2014 tsuru-circus authors. All rights reserved.
 # Use of this source code is governed by a BSD-style
 # license that can be found in the LICENSE file.
 
@@ -21,6 +21,7 @@ class Stream(object):
     def __init__(self, **kwargs):
         self.apprc = "/home/application/apprc"
         self.watcher_name = kwargs.get("watcher_name", "")
+        self.timeout = kwargs.get("timeout", 2)
 
     def __call__(self, data):
         appname, host, token = self.load_envs()
@@ -28,8 +29,12 @@ class Stream(object):
             url = "{0}/apps/{1}/log?source={2}".format(host, appname,
                                                        self.watcher_name)
             messages = extract_message(data["data"])
-            requests.post(url, data=json.dumps(messages),
-                          headers={"Authorization": "bearer " + token})
+            try:
+                requests.post(url, data=json.dumps(messages),
+                              headers={"Authorization": "bearer " + token},
+                              timeout=self.timeout)
+            except:
+                pass
 
     def load_envs(self):
         envs = common.load_envs(self.apprc)
