@@ -1,4 +1,4 @@
-# Copyright 2013 tsuru-circus authors. All rights reserved.
+# Copyright 2014 tsuru-circus authors. All rights reserved.
 # Use of this source code is governed by a BSD-style
 # license that can be found in the LICENSE file.
 
@@ -34,7 +34,28 @@ class StreamTestCase(unittest.TestCase):
         expected_msg = "Starting gunicorn 0.15.0\n"
         expected_data = json.dumps([expected_msg])
         post.assert_called_with(url, data=expected_data,
-                                headers={"Authorization": "bearer " + token})
+                                headers={"Authorization": "bearer " + token},
+                                timeout=2)
+
+    @mock.patch("requests.post")
+    def test_timeout_is_configurable(self, post):
+        post.return_value = mock.Mock(status_code=200)
+        stream = Stream(watcher_name="watcher", timeout=10)
+        stream.apprc = os.path.join(os.path.dirname(__file__),
+                                    "testdata/apprc")
+        stream(self.data)
+        appname, host, token = stream.load_envs()
+        url = "{0}/apps/{1}/log?source=watcher".format(host, appname)
+        expected_msg = "Starting gunicorn 0.15.0\n"
+        expected_data = json.dumps([expected_msg])
+        post.assert_called_with(url, data=expected_data,
+                                headers={"Authorization": "bearer " + token},
+                                timeout=10)
+
+    @mock.patch("requests.post")
+    def test_should_ignore_errors_in_post_call(self, post):
+        post.side_effect = Exception()
+        self.stream(self.data)
 
     @mock.patch("tsuru.common.load_envs")
     def test_should_slience_errors_when_envs_does_not_exist(lenvs, self):
